Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(621)

Unified Diff: third_party/WebKit/Source/platform/graphics/GraphicsLayer.cpp

Issue 2387883002: Use float for scroll offset. (Closed)
Patch Set: Fix README.md Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/platform/graphics/GraphicsLayer.cpp
diff --git a/third_party/WebKit/Source/platform/graphics/GraphicsLayer.cpp b/third_party/WebKit/Source/platform/graphics/GraphicsLayer.cpp
index 898e54807f2c45f42e1898c63a7d5ba1e10b2d66..9b5d7441f068f32f5e388e98b84f898c26c8785e 100644
--- a/third_party/WebKit/Source/platform/graphics/GraphicsLayer.cpp
+++ b/third_party/WebKit/Source/platform/graphics/GraphicsLayer.cpp
@@ -1117,16 +1117,16 @@ void GraphicsLayer::setScrollableArea(ScrollableArea* scrollableArea,
void GraphicsLayer::didScroll() {
if (m_scrollableArea) {
- DoublePoint newPosition =
- -m_scrollableArea->scrollOrigin() +
- toDoubleSize(m_layer->layer()->scrollPositionDouble());
+ ScrollOffset newOffset =
+ toFloatSize(m_layer->layer()->scrollPositionDouble() -
+ m_scrollableArea->scrollOrigin());
- // FrameView::setScrollPosition() doesn't work for compositor commits
+ // FrameView::setScrollOffset() doesn't work for compositor commits
// (interacts poorly with programmatic scroll animations) so we need to use
// the ScrollableArea version. The FrameView method should go away soon
// anyway.
- m_scrollableArea->ScrollableArea::setScrollPosition(newPosition,
- CompositorScroll);
+ m_scrollableArea->ScrollableArea::setScrollOffset(newOffset,
+ CompositorScroll);
}
}

Powered by Google App Engine
This is Rietveld 408576698